@@ -27,7 +27,7 @@ def MakeRoute(data: ValidatedTemplate) -> Iterator[Route]:
         SDES=data.EDEL,
         DLMC=1,
         DLAC=1,
-        TSID=data.EDEU.replace('TBD', '')[:4]
+        TSID=data.TSID
     )
 
 
@@ -105,6 +105,7 @@ def MakeCustomerExtension(data: ValidatedTemplate) -> Iterator[CustomerExtension
             FILE='DROUDI',
             PK01=data.ROUT,
             PK02=RODN,
+            A030=data.EDEU,
             N096=data.PCUD if data.PCUD else None,
             N196=data.PCUH if data.PCUH else None,
             N296=data.PCUM if data.PCUM else None
