@@ -120,6 +120,7 @@ class UnvalidatedTemplate(BaseModel):
     ROUT: Optional[Any] = ROUT(None)
     EDEL: Optional[Any] = EDEL(None)
     EDEU: Optional[Any] = EDEU(None)
+    TSID: Optional[Any] = TSID(None)
     MODL: Optional[Any] = MODL(None)
     RODN: Optional[Any] = RODN(None)
     DDOW: Optional[Any] = DDOW(None)
@@ -158,6 +159,7 @@ class ValidatedTemplate(UnvalidatedTemplate):
     ROUT: str = ROUT(..., min_length=6, max_length=6, regex=REGEX_STR_ROUTE)
     EDEL: str = EDEL(..., min_length=3, max_length=4, regex=REGEX_STR_PLACE_OF_LOAD)
     EDEU: str = EDEU(..., min_length=3, max_length=4, regex=REGEX_STR_PLACE_OF_UNLOAD)
+    TSID: Optional[str] = TSID(..., max_length=4)
     RODN: Optional[PositiveInt] = RODN(...)
     MODL: str = MODL(..., min_length=2, max_length=3, regex=REGEX_STR_MODE_OF_TRANSPORT)
     DDOW: str = DDOW(..., min_length=7, max_length=7, regex=REGEX_STR_DEPARTURE_DAYS)
@@ -180,7 +182,7 @@ class Route(BaseModel):
     SDES: str = SDES(..., max_length=4)
     DLMC: NonNegativeInt = DLMC(...)
     DLAC: NonNegativeInt = DLAC(...)
-    TSID: str = TSID(..., max_length=4)
+    TSID: Optional[str] = TSID(..., max_length=4)
 
 
 class Departure(BaseModel):
